@@ -46,7 +46,7 @@ func (d dockerRuntime) Provision(ctx context.Context) error {
 	// daemon.json
 	a.Add(func() error {
 		// not a fatal error
-		if err := d.createDaemonFile(conf.Docker); err != nil {
+		if err := d.createDaemonFile(conf.Docker, conf.Env); err != nil {
 			log.Warnln(err)
 		}
 		return nil
@@ -58,6 +58,11 @@ func (d dockerRuntime) Provision(ctx context.Context) error {
 		a.Add(d.useContext)
 	}
 
+	// validate docker socket access
+	a.Add(func() error {
+		return d.guest.RunQuiet("sh", "-c", "sudo chown ${USER} /var/run/docker.sock")
+	})
+
 	return a.Exec()
 }
 
